Package: CTdata
Title: Data companion to CTexploreR
Version: 1.12.0
Authors@R: 
    c(person(given = "Axelle",
           family = "Loriot",
           role = "aut",
           email = "axelle.loriot@uclouvain.be",
                 comment = c(ORCID = "0000-0002-5288-8561")),
      person(given = "Julie",
           family = "Devis",
           role = "aut",
           email = "julie.devis@uclouvain.be",
           comment = c(ORCID = "0000-0001-5525-5666")),
      person(given = "Anna",
           family = "Diacofotaki",
           role = "ctb",
           email = "anna.diacofotaki@uclouvain.be"),
      person(given = "Charles",
           family = "De Smet",
           role = "ths",
           email = "charles.desmet@uclouvain.be"),
      person(given = "Laurent",
           family = "Gatto",
           role = c("aut","ths", "cre"),
           email = "laurent.gatto@uclouvain.be",
           comment = c(ORCID = "0000-0002-1520-2268")))
Description: Data from publicly available databases (GTEx, CCLE, TCGA
      and ENCODE) that go with CTexploreR in order to re-define a
      comprehensive and thoroughly curated list of CT genes and their
      main characteristics.
License: Artistic-2.0
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Depends: R (>= 4.2)
biocViews: Transcriptomics, Epigenetics, GeneExpression, DataImport,
        ExperimentHubSoftware
Imports: ExperimentHub, utils
Suggests: testthat (>= 3.0.0), DT, BiocStyle, knitr, rmarkdown,
        SummarizedExperiment, SingleCellExperiment
VignetteBuilder: knitr
BugReports: https://github.com/UCLouvain-CBIO/CTdata/issues
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/CTdata
git_branch: RELEASE_3_23
git_last_commit: 875c873
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:52:42 UTC; biocbuild
Author: Axelle Loriot [aut] (ORCID: <https://orcid.org/0000-0002-5288-8561>),
  Julie Devis [aut] (ORCID: <https://orcid.org/0000-0001-5525-5666>),
  Anna Diacofotaki [ctb],
  Charles De Smet [ths],
  Laurent Gatto [aut, ths, cre] (ORCID:
    <https://orcid.org/0000-0002-1520-2268>)
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>
Built: R 4.6.0; ; 2026-04-29 04:38:59 UTC; unix
