# CTdata

Companion Package for CTexploreR containing omics data to select and characterise CT genes. 

Data comes from public databases. One can find in this package, expression and methylation values of genes in normal and tumor samples as well as in tumor cell lines. Expression in cells treated with a demethylating agent is also available. 

A list of defined CT genes and their characteristics can also be found in the package
